@@ -14,9 +14,9 @@
 =end
 
 
-vr_DIR="vr/" unless vr_DIR
-require vr_DIR+'vruby'
-require vr_DIR+'vrcontrol'
+VR_DIR="vr/" unless defined?(::VR_DIR)
+require VR_DIR+'vruby'
+require VR_DIR+'vrcontrol'
 
 class VRDialogTemplate
 =begin
@@ -142,6 +142,28 @@ module WMsg
 end
 
 class VRDialogComponent < SWin::Dialog
+=begin
+== VRDialogComponent
+This class represents modal/modeless dialogs.
+--- setButtonAs(button,dlgbuttonid)
+    Set the button as dialog's functional button like IDOK, IDCANCEL and so on.
+    ((|button|)) must be a VRButton and dlgbuttonid must be between IDOK and IDHELP
+--- centering
+    set the dialog at the center of the parent window.
+=end
+
+  include VRParent
+
+  IDOK             = 1
+  IDCANCEL         = 2
+  IDABORT          = 3
+  IDRETRY          = 4
+  IDIGNORE         = 5
+  IDYES            = 6
+  IDNO             = 7
+  IDCLOSE          = 8
+  IDHELP = DLGMAX_ID  = 9
+
   attr :options,1  #hash
 
   def vrinit
@@ -155,6 +177,16 @@ class VRDialogComponent < SWin::Dialog
     self.open(*arg)
   end
 
+  def setButtonAs(control, newid) #contributed by Katonbo-san.
+    if newid > DLGMAX_ID then
+      raise "id[#{newid}] is too big"
+    end
+    id = control.etc
+    @controls[newid] = @controls[id]
+#    control.etc = newid
+#    @controls.delete(id)
+  end
+
   def centering(target = @parent) #contributed by Yuya-san./modified by nyasu.
     unless target.is_a?(SWin::Window) then
       target = @screen
@@ -204,6 +236,11 @@ class VRDialogComponent < SWin::Dialog
       super
     end
   end
+
+  def open(parent=@parent,modal=true)
+    @parent=parent
+    super parent,modal
+  end
 end
 
 
@@ -220,18 +257,12 @@ at VRModalDialog#close(value). <- SWin::Dialog#close
 Hash of ((|options|)) set values as 'options["cancelbutton"]=canbtn'
 
 === Methods
---- open(parent=@parent)
-    See SWin::Dialog#open
 --- close(value)
     See SWin::Dialog#close
 =end
 
   include VRParent
 
-  def open(parent=@parent)
-    @parent=parent
-    super
-  end
 end
 
 class VRModelessDialog <VRDialogComponent
@@ -246,15 +277,14 @@ Hash of ((|options|)) set values as 'options["cancelbutton"]=canbtn'
 
 === Methods
 --- open(parent=@parent)
-    See SWin::Dialog#open
+    See SWin::Dialog#open.
 --- close(value)
     See SWin::Dialog#close
 =end
 
   include VRParent
 
-  def open(parent=@parent)
-    @parent=parent
+  def open(parent=@parent,ignored_modal=false)
     super parent,false
   end
 end
@@ -296,11 +326,10 @@ A method is added to VRScreen by loading this file.
     template,options = *template_arg
     template = PlaneDialogTemplate unless template
     options = {} unless options
-
     if mod.is_a?(Class) and mod.ancestors.index(VRDialogComponent) then
       frm=@factory.newdialog(template,mod)
     elsif mod.is_a?(Class) then
-      raise "#{mod.type} is not a descendant of VRDialogComponent"
+      raise "#{mod.class} is not a descendant of VRDialogComponent"
     elsif mod.is_a?(Module) then
       frm=@factory.newdialog(template,VRDialogComponent)
       frm.extend VRParent
@@ -321,13 +350,15 @@ A method is added to VRScreen by loading this file.
   def openModalDialog(parent,style=nil,mod=VRModalDialog,*template_arg)
     mod = VRModalDialog unless mod
     frm = newdialog(parent,style,mod,*template_arg)
-    frm.open()
+    a = frm.open(parent,true)
   end
 
   def openModelessDialog(parent,style=nil,mod=VRModelessDialog,*template_arg)
     mod = VRModelessDialog unless mod
     frm = newdialog(parent,style,mod,*template_arg)
-    frm.open
+    frm.open parent,false
+    @_vr_box.push frm
+    frm
   end
 
   alias modalform :openModalDialog
