@@ -1,25 +1,26 @@
 
 #==============================================================================#
-# exerb/config.rb
-# $Id: config.rb,v 1.2 2002/12/25 06:38:50 yuya Exp $
+# $Id: config.rb,v 1.13 2003/11/17 19:33:12 yuya Exp $
 #==============================================================================#
 
+require 'rbconfig'
+
 #==============================================================================#
-# Exerb Module
+
 module Exerb
 
-  def self.find_core(filename)
-    filepath = File.join(File.dirname(__FILE__), filename)
-    return (File.exist?(filepath) ? filepath : nil)
+  CORE_PATH   = [File.join(Config::CONFIG['datadir'], 'exerb'), '.']
+  CORE_NAME   = {'cui' => 'ruby181c.exc', 'cuirt' => 'ruby181crt.exc', 'gui' => 'ruby181g.exc', 'guirt' => 'ruby181grt.exc'}
+  PLUGIN_PATH = [File.join(Config::CONFIG['datadir'], 'exerb'), '.']
+  PLUGIN_NAME = {'zlib' => 'mod_zlib.exm', 'bruby' => 'mod_bruby.exm'}
+
+  if $Exerb
+    selfpath = File.dirname(Exerb.filepath)
+    CORE_PATH   << selfpath
+    PLUGIN_PATH << selfpath
   end
-  private_class_method :find_core
 
-  CORE = {
-    'cui' => find_core('ruby168c.rbx'),
-    'gui' => find_core('ruby168g.rbx'),
-  }
-
-end
+end # Exerb
 
 #==============================================================================#
 
